/****************************************************************************
** Meta object code from reading C++ file 'UIFileManagerTable.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/VBox/Frontends/VirtualBox/src/guestctrl/UIFileManagerTable.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UIFileManagerTable.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN28UIDirectoryDiskUsageComputerE_t {};
} // unnamed namespace

template <> constexpr inline auto UIDirectoryDiskUsageComputer::qt_create_metaobjectdata<qt_meta_tag_ZN28UIDirectoryDiskUsageComputerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UIDirectoryDiskUsageComputer",
        "sigResultUpdated",
        "",
        "UIDirectoryStatistics"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigResultUpdated'
        QtMocHelpers::SignalData<void(UIDirectoryStatistics)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UIDirectoryDiskUsageComputer, qt_meta_tag_ZN28UIDirectoryDiskUsageComputerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UIDirectoryDiskUsageComputer::staticMetaObject = { {
    QMetaObject::SuperData::link<QThread::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28UIDirectoryDiskUsageComputerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28UIDirectoryDiskUsageComputerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN28UIDirectoryDiskUsageComputerE_t>.metaTypes,
    nullptr
} };

void UIDirectoryDiskUsageComputer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UIDirectoryDiskUsageComputer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigResultUpdated((*reinterpret_cast<std::add_pointer_t<UIDirectoryStatistics>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< UIDirectoryStatistics >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UIDirectoryDiskUsageComputer::*)(UIDirectoryStatistics )>(_a, &UIDirectoryDiskUsageComputer::sigResultUpdated, 0))
            return;
    }
}

const QMetaObject *UIDirectoryDiskUsageComputer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UIDirectoryDiskUsageComputer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28UIDirectoryDiskUsageComputerE_t>.strings))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int UIDirectoryDiskUsageComputer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void UIDirectoryDiskUsageComputer::sigResultUpdated(UIDirectoryStatistics _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN18UIPropertiesDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto UIPropertiesDialog::qt_create_metaobjectdata<qt_meta_tag_ZN18UIPropertiesDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UIPropertiesDialog"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UIPropertiesDialog, qt_meta_tag_ZN18UIPropertiesDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UIPropertiesDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QIDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18UIPropertiesDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18UIPropertiesDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18UIPropertiesDialogE_t>.metaTypes,
    nullptr
} };

void UIPropertiesDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UIPropertiesDialog *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *UIPropertiesDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UIPropertiesDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18UIPropertiesDialogE_t>.strings))
        return static_cast<void*>(this);
    return QIDialog::qt_metacast(_clname);
}

int UIPropertiesDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QIDialog::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN18UIFileManagerTableE_t {};
} // unnamed namespace

template <> constexpr inline auto UIFileManagerTable::qt_create_metaobjectdata<qt_meta_tag_ZN18UIFileManagerTableE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UIFileManagerTable",
        "sigLogOutput",
        "",
        "strLog",
        "strMachineName",
        "FileManagerLogType",
        "eLogType",
        "sigDeleteConfirmationOptionChanged",
        "sigSelectionChanged",
        "fHasSelection",
        "sigAltDoubleClick",
        "sltReceiveDirectoryStatistics",
        "UIDirectoryStatistics",
        "statictics",
        "sltCreateNewDirectory",
        "sltItemDoubleClicked",
        "QModelIndex",
        "index",
        "sltItemClicked",
        "sltAltDoubleClick",
        "sltGoUp",
        "sltGoHome",
        "sltGoForward",
        "sltGoBackward",
        "sltRefresh",
        "sltDelete",
        "sltRename",
        "sltCopy",
        "sltCut",
        "sltPaste",
        "sltShowProperties",
        "sltSelectAll",
        "sltInvertSelection",
        "sltRetranslateUI",
        "sltCreateFileViewContextMenu",
        "QPoint",
        "point",
        "sltSelectionChanged",
        "QItemSelection",
        "selected",
        "deselected",
        "sltSearchTextChanged",
        "strText",
        "sltHandleItemRenameAttempt",
        "UIFileSystemItem*",
        "pItem",
        "strOldPath",
        "strOldName",
        "strNewName",
        "sltHandleNavigationWidgetPathChange",
        "strPath",
        "sltHandleNavigationWidgetHistoryListChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigLogOutput'
        QtMocHelpers::SignalData<void(QString, const QString &, FileManagerLogType)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'sigDeleteConfirmationOptionChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigSelectionChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'sigAltDoubleClick'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sltReceiveDirectoryStatistics'
        QtMocHelpers::SlotData<void(UIDirectoryStatistics)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'sltCreateNewDirectory'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sltItemDoubleClicked'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'sltItemClicked'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'sltAltDoubleClick'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sltGoUp'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sltGoHome'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sltGoForward'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sltGoBackward'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sltRefresh'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sltDelete'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sltRename'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sltCopy'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sltCut'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sltPaste'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sltShowProperties'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sltSelectAll'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sltInvertSelection'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sltRetranslateUI'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'sltCreateFileViewContextMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Slot 'sltSelectionChanged'
        QtMocHelpers::SlotData<void(const QItemSelection &, const QItemSelection &)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 38, 39 }, { 0x80000000 | 38, 40 },
        }}),
        // Slot 'sltSearchTextChanged'
        QtMocHelpers::SlotData<void(const QString &)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 42 },
        }}),
        // Slot 'sltHandleItemRenameAttempt'
        QtMocHelpers::SlotData<void(UIFileSystemItem *, const QString &, const QString &, const QString &)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 44, 45 }, { QMetaType::QString, 46 }, { QMetaType::QString, 47 }, { QMetaType::QString, 48 },
        }}),
        // Slot 'sltHandleNavigationWidgetPathChange'
        QtMocHelpers::SlotData<void(const QString &)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 50 },
        }}),
        // Slot 'sltHandleNavigationWidgetHistoryListChanged'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UIFileManagerTable, qt_meta_tag_ZN18UIFileManagerTableE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UIFileManagerTable::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18UIFileManagerTableE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18UIFileManagerTableE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18UIFileManagerTableE_t>.metaTypes,
    nullptr
} };

void UIFileManagerTable::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UIFileManagerTable *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigLogOutput((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<FileManagerLogType>>(_a[3]))); break;
        case 1: _t->sigDeleteConfirmationOptionChanged(); break;
        case 2: _t->sigSelectionChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->sigAltDoubleClick(); break;
        case 4: _t->sltReceiveDirectoryStatistics((*reinterpret_cast<std::add_pointer_t<UIDirectoryStatistics>>(_a[1]))); break;
        case 5: _t->sltCreateNewDirectory(); break;
        case 6: _t->sltItemDoubleClicked((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 7: _t->sltItemClicked((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 8: _t->sltAltDoubleClick(); break;
        case 9: _t->sltGoUp(); break;
        case 10: _t->sltGoHome(); break;
        case 11: _t->sltGoForward(); break;
        case 12: _t->sltGoBackward(); break;
        case 13: _t->sltRefresh(); break;
        case 14: _t->sltDelete(); break;
        case 15: _t->sltRename(); break;
        case 16: _t->sltCopy(); break;
        case 17: _t->sltCut(); break;
        case 18: _t->sltPaste(); break;
        case 19: _t->sltShowProperties(); break;
        case 20: _t->sltSelectAll(); break;
        case 21: _t->sltInvertSelection(); break;
        case 22: _t->sltRetranslateUI(); break;
        case 23: _t->sltCreateFileViewContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 24: _t->sltSelectionChanged((*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[2]))); break;
        case 25: _t->sltSearchTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: _t->sltHandleItemRenameAttempt((*reinterpret_cast<std::add_pointer_t<UIFileSystemItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 27: _t->sltHandleNavigationWidgetPathChange((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: _t->sltHandleNavigationWidgetHistoryListChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< UIDirectoryStatistics >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QItemSelection >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UIFileManagerTable::*)(QString , const QString & , FileManagerLogType )>(_a, &UIFileManagerTable::sigLogOutput, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIFileManagerTable::*)()>(_a, &UIFileManagerTable::sigDeleteConfirmationOptionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIFileManagerTable::*)(bool )>(_a, &UIFileManagerTable::sigSelectionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIFileManagerTable::*)()>(_a, &UIFileManagerTable::sigAltDoubleClick, 3))
            return;
    }
}

const QMetaObject *UIFileManagerTable::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UIFileManagerTable::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18UIFileManagerTableE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int UIFileManagerTable::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    return _id;
}

// SIGNAL 0
void UIFileManagerTable::sigLogOutput(QString _t1, const QString & _t2, FileManagerLogType _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void UIFileManagerTable::sigDeleteConfirmationOptionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void UIFileManagerTable::sigSelectionChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void UIFileManagerTable::sigAltDoubleClick()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
